@@ -15,7 +15,10 @@ import plotly.express as px
 
 class Surface:
     def __init__(self, df, datestr, putcall, symbol):
-        self.df = df.sort_values(["delta", "strike"], ascending=[putcall == "C"] * 2)
+        # Need to sort the tail ends by putCall
+        self.df = df.sort_values(
+            ["delta", "strike"], ascending=[putcall == "C", putcall != "C"]
+        )
         self.day = datestr
         self.putCall = putcall
         self.symbol = symbol
@@ -59,7 +62,7 @@ class Surface:
     def getIvFromStrikeAndDte(self, strike, dte):
         curves = sorted(self.curves, key=lambda x: x.dte)
         lowestIv = lowestDte = highestIv = highestDte = 0
-        for idx in range(len(curves)):
+        for idx in range(len(curves))[::-1]:
             if dte < curves[idx].dte:
                 lowestIv = curves[idx].getIvFromStrike(strike)
                 lowestDte = curves[idx].dte
@@ -138,7 +141,9 @@ class Curve:
     def getIvFromStrike(self, strike):
         assert strike > 0
         lowestIv = lowestStrike = highestIv = highestStrike = 0
-        for idx in range(len(self.strikes)):
+        # Reverse the strikes if call.
+        should_reverse = -1 if self.putCall == "C" else 1
+        for idx in range(len(self.strikes))[::should_reverse]:
             if strike < self.strikes[idx]:
                 lowestIv = self.markIvs[idx]
                 lowestStrike = self.strikes[idx]
@@ -147,7 +152,7 @@ class Curve:
                 highestIv = self.markIvs[idx]
                 highestStrike = self.strikes[idx]
 
-        #         print(highestIv, highestDelta, lowestIv, lowestDelta)
+        print(highestIv, highestStrike, lowestIv, lowestStrike)
         if lowestStrike == 0:
             return self.markIvs[idx]
         elif highestStrike == 0:
